==> ejc-zdscost-impl-3.0.0-20251013.055108-149-sources.jar: com/ejianc/business/zdscost/controller/api/BudgetProjectDetailApi.java <==
package com.ejianc.business.zdscost.controller.api;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.zdscost.bean.BudgetProjectChangeEntity;
import com.ejianc.business.zdscost.bean.BudgetProjectDetailChangeEntity;
import com.ejianc.business.zdscost.bean.BudgetProjectDetailEntity;
import com.ejianc.business.zdscost.bean.BudgetProjectEntity;
import com.ejianc.business.zdscost.consts.ChangTypeConst;
import com.ejianc.business.zdscost.service.IBudgetProjectChangeService;
import com.ejianc.business.zdscost.service.IBudgetProjectDetailChangeService;
import com.ejianc.business.zdscost.service.IBudgetProjectDetailService;
import com.ejianc.business.zdscost.service.IBudgetProjectService;
import com.ejianc.business.zdscost.vo.BudgetProjectDetailVO;
import com.ejianc.business.zdscost.vo.query.BudgetProjectDetailQueryVO;
import com.ejianc.business.zdsmaterial.plan.conjecture.vo.MaterialConjectureVO;
import com.ejianc.framework.cache.redissonlock.RedissonLocker;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import jodd.util.StringUtil;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 切包清单-明细
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("budgetProjectDetailApi")
@Api(value = "切包清单-查询Api", tags = {"切包清单-查询Api"})
public class BudgetProjectDetailApi implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBudgetProjectService budgetProjectService;

    @Autowired
    private IBudgetProjectDetailService detailService;

    @Autowired
    private IBudgetProjectChangeService budgetProjectChangeService;

    @Autowired
    private IBudgetProjectDetailChangeService detailChangeService;

    @Autowired
    private IBudgetProjectDetailService service;

    @Autowired
    private RedissonLocker redissonLocker;

    @RequestMapping(value = "/updateMaterialConjecture", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> updateMaterialConjecture(@RequestBody List<MaterialConjectureVO> list) {
        if (CollectionUtils.isNotEmpty(list)) {
            Map<Long, MaterialConjectureVO> map = list.stream()
                    .collect(Collectors.toMap(
                            MaterialConjectureVO::getBudgetDetailId, student -> student, (k1, k2) -> k1));
            Long billId = list.get(0).getBillId();
            BudgetProjectEntity entity = budgetProjectService.selectById(billId);
            if (entity != null) {
                List<BudgetProjectDetailEntity> detailEntities = new ArrayList<>();
                for (BudgetProjectDetailEntity detailEntity : entity.getBudgetProjectDetailList()) {
                    Long id = detailEntity.getId();
                    MaterialConjectureVO materialConjectureVO = map.get(id);
                    if (materialConjectureVO != null) {
                        detailEntity.setMateType(materialConjectureVO.getMateType());
                        detailEntity.setMaterialId(materialConjectureVO.getActualMaterialId());
                        detailEntity.setMaterialCode(materialConjectureVO.getActualMaterialCode());
                        detailEntity.setMaterialName(materialConjectureVO.getActualMaterialName());
                        detailEntity.setMaterialSpec(materialConjectureVO.getActualMaterialSpec());
                        detailEntities.add(detailEntity);
                    }
                }
                if (CollectionUtils.isNotEmpty(detailEntities)) {
                    detailService.saveOrUpdateBatch(detailEntities);
                }
                LambdaUpdateWrapper<BudgetProjectEntity> updateWrapper = new LambdaUpdateWrapper<>();
                updateWrapper.eq(BudgetProjectEntity::getId, billId);
                updateWrapper.set(BudgetProjectEntity::getIdentificationState, 2);
                budgetProjectService.update(updateWrapper);
            } else {
                BudgetProjectChangeEntity changeEntity = budgetProjectChangeService.selectById(billId);
                if (changeEntity != null) {
                    List<BudgetProjectDetailChangeEntity> detailEntities = new ArrayList<>();
                    for (BudgetProjectDetailChangeEntity detailEntity : changeEntity.getBudgetProjectDetailList()) {
                        Long id = detailEntity.getId();
                        MaterialConjectureVO materialConjectureVO = map.get(id);
                        if (materialConjectureVO != null) {
                            detailEntity.setMateType(materialConjectureVO.getMateType());
                            detailEntity.setMaterialId(materialConjectureVO.getActualMaterialId());
                            detailEntity.setMaterialCode(materialConjectureVO.getActualMaterialCode());
                            detailEntity.setMaterialName(materialConjectureVO.getActualMaterialName());
                            detailEntity.setMaterialSpec(materialConjectureVO.getActualMaterialSpec());
                            detailEntities.add(detailEntity);
                        }
                    }
                    if (CollectionUtils.isNotEmpty(detailEntities)) {
                        detailChangeService.saveOrUpdateBatch(detailEntities);
                    }
                    LambdaUpdateWrapper<BudgetProjectChangeEntity> updateWrapper = new LambdaUpdateWrapper<>();
                    updateWrapper.eq(BudgetProjectChangeEntity::getId, billId);
                    updateWrapper.set(BudgetProjectChangeEntity::getIdentificationState, 2);
                    budgetProjectChangeService.update(updateWrapper);
                }
            }

            logger.info("updateMaterialConjecture回调-------{}---------", billId);
            String lockKey = "AiMaterialKey_" + billId;
            redissonLocker.unlock(lockKey);
        }
        return CommonResponse.success("更新物料识别结果数据成功！");
    }

    @ApiOperation("项目费用包接口")
    @RequestMapping(value = "/queryPackageList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<Map>> queryPackageList(@RequestBody BudgetProjectDetailQueryVO queryVO) {
        if (queryVO.getProjectSid() == null || queryVO.getPageSize() == null || queryVO.getPageIndex() == null) {
            throw new BusinessException("参数项目ID[projectId/projectSid]不能为空！");
        }
        if (queryVO.getPageSize() == null) {
            throw new BusinessException("参数每页行数[pageSize]不能为空！");
        }
        if (queryVO.getPageIndex() == null) {
            throw new BusinessException("参数页码[pageIndex]不能为空！");
        }
        Page<Map> page = new Page<>((long) queryVO.getPageIndex(), (long) queryVO.getPageSize());
        List<Map> list = service.queryPackageList(page, queryVO);
        for (Map map : list) {
            if (!map.containsKey("materialCode")){
                map.put("materialCode",null);
            }
            if (!map.containsKey("materialId")){
                map.put("materialId",null);
            }
            if (!map.containsKey("materialName")){
                map.put("materialName",null);
            }
            if (!map.containsKey("materialSpec")){
                map.put("materialSpec",null);
            }
        }
        IPage<Map> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(list);
        return CommonResponse.success("查询列表数据成功！", pageData);
    }


    @ApiOperation("切包清单接口")
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<Page<BudgetProjectDetailVO>> queryList(@RequestBody BudgetProjectDetailQueryVO queryVO) {
        if (queryVO.getProjectId() == null && queryVO.getProjectSid() == null) {
            throw new BusinessException("参数项目ID[projectId/projectSid]不能为空！");
        }
        LambdaQueryWrapper<BudgetProjectEntity> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(null != queryVO.getProjectSid(), BudgetProjectEntity::getProjectSid, queryVO.getProjectSid());
        queryWrapper.eq(null != queryVO.getProjectId(), BudgetProjectEntity::getProjectId, queryVO.getProjectId());
        queryWrapper.in(BudgetProjectEntity::getBillState, "1,3");
        queryWrapper.orderByDesc(BudgetProjectEntity::getCreateTime);
        List<BudgetProjectEntity> list1 = budgetProjectService.list(queryWrapper);
        Long budgetId = 1L;
        if (CollectionUtils.isNotEmpty(list1)) {
            budgetId = list1.get(0).getId();
        }

        QueryParam queryParam = new QueryParam();
        if (null != queryVO.getPageSize()) {
            queryParam.setPageSize(queryVO.getPageSize());
        }
        if (null != queryVO.getPageIndex()) {
            queryParam.setPageIndex(queryVO.getPageIndex());
        }
        Map<String, Parameter> params = queryParam.getParams();
        String paramStr = queryVO.getParamStr();
        if (StringUtils.isNotEmpty(paramStr)) {
            String[] split = paramStr.split(",");
            //专业编码,专业名称,包标识,包代码,包名称
            if (split.length > 0 && StringUtil.isNotBlank(split[0])) {
                params.put("bigPackCode", new Parameter(QueryParam.LIKE, split[0]));
            }
            if (split.length > 1 && StringUtil.isNotBlank(split[1])) {
                params.put("bigPackName", new Parameter(QueryParam.LIKE, split[1]));
            }
            if (split.length > 2 && StringUtil.isNotBlank(split[2])) {
                if ("engineering".equals(split[2])) {
                    params.put("engineeringListFlag", new Parameter(QueryParam.EQ, 1));
                } else {
                    params.put("materialListFlag", new Parameter(QueryParam.EQ, 1));
                }
            }
            if (split.length > 3 && StringUtil.isNotBlank(split[3])) {
                params.put("SQL", new Parameter(QueryParam.SQL, "(engineering_pack_code = '" + split[3] + "' or material_pack_code = '" + split[3] + "' )"));
            }
            if (split.length > 4 && StringUtil.isNotBlank(split[4])) {
                params.put("SQL", new Parameter(QueryParam.SQL, "(engineering_pack_name = '" + split[4] + "' or material_pack_name = '" + split[4] + "' )"));
            }
        }
        /** 租户隔离 */
        params.put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        params.put("budgetId", new Parameter(QueryParam.EQ, budgetId));
        params.put("changeType", new Parameter(QueryParam.NE, ChangTypeConst.DELETE));
        if (null != queryVO.getMaterialPackIds()) {
            params.put("materialPackId", new Parameter(QueryParam.IN, queryVO.getMaterialPackIds()));
        }
        if (null != queryVO.getMaterialPackCodes()) {
            params.put("materialPackCode", new Parameter(QueryParam.IN, queryVO.getMaterialPackCodes()));
        }
        if (null != queryVO.getBudgetDetailIds()) {
            params.put("id", new Parameter(QueryParam.IN, queryVO.getBudgetDetailIds()));
        }
        IPage<BudgetProjectDetailEntity> entityIPage = service.queryPage(queryParam, false);
        Page<BudgetProjectDetailVO> pageData = new Page<>(entityIPage.getCurrent(), entityIPage.getSize(), entityIPage.getTotal());
        List<BudgetProjectDetailVO> detailVOS = BeanMapper.mapList(entityIPage.getRecords(), BudgetProjectDetailVO.class);
        for (BudgetProjectDetailVO detailVO : detailVOS) {
            detailVO.setMaterialPackName(null != detailVO.getMaterialPackCode() ?
                    detailVO.getMaterialPackName() + detailVO.getMaterialPackCode() : detailVO.getMaterialPackName());
            detailVO.setEngineeringPackName(null != detailVO.getEngineeringPackCode() ?
                    detailVO.getEngineeringPackName() + detailVO.getEngineeringPackCode() : detailVO.getEngineeringPackName());
        }
        pageData.setRecords(detailVOS);
        return CommonResponse.success("查询列表数据成功！", pageData);
    }


}

==> ejc-zdscost-impl-3.0.0-20251203.025344-153-sources.jar: com/ejianc/business/zdscost/controller/api/BudgetProjectDetailApi.java <==
package com.ejianc.business.zdscost.controller.api;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.zdscost.bean.BudgetProjectChangeEntity;
import com.ejianc.business.zdscost.bean.BudgetProjectDetailChangeEntity;
import com.ejianc.business.zdscost.bean.BudgetProjectDetailEntity;
import com.ejianc.business.zdscost.bean.BudgetProjectEntity;
import com.ejianc.business.zdscost.consts.ChangTypeConst;
import com.ejianc.business.zdscost.service.IBudgetProjectChangeService;
import com.ejianc.business.zdscost.service.IBudgetProjectDetailChangeService;
import com.ejianc.business.zdscost.service.IBudgetProjectDetailService;
import com.ejianc.business.zdscost.service.IBudgetProjectService;
import com.ejianc.business.zdscost.vo.BudgetProjectDetailVO;
import com.ejianc.business.zdscost.vo.query.BudgetProjectDetailQueryVO;
import com.ejianc.business.zdsmaterial.plan.conjecture.constants.ConjectureConstants;
import com.ejianc.business.zdsmaterial.plan.conjecture.vo.MaterialConjectureVO;
import com.ejianc.framework.cache.redissonlock.RedissonLocker;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import jodd.util.StringUtil;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 切包清单-明细
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("budgetProjectDetailApi")
@Api(value = "切包清单-查询Api", tags = {"切包清单-查询Api"})
public class BudgetProjectDetailApi implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBudgetProjectService budgetProjectService;

    @Autowired
    private IBudgetProjectDetailService detailService;

    @Autowired
    private IBudgetProjectChangeService budgetProjectChangeService;

    @Autowired
    private IBudgetProjectDetailChangeService detailChangeService;

    @Autowired
    private IBudgetProjectDetailService service;

    @Autowired
    private RedissonLocker redissonLocker;

    @RequestMapping(value = "/updateMaterialConjecture", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> updateMaterialConjecture(@RequestBody List<MaterialConjectureVO> list) {
        if (CollectionUtils.isNotEmpty(list)) {
            Map<Long, MaterialConjectureVO> map = list.stream()
                    .collect(Collectors.toMap(
                            MaterialConjectureVO::getBudgetDetailId, student -> student, (k1, k2) -> k1));
            Long billId = list.get(0).getBillId();
            BudgetProjectEntity entity = budgetProjectService.selectById(billId);
            if (entity != null) {
                List<BudgetProjectDetailEntity> detailEntities = new ArrayList<>();
                for (BudgetProjectDetailEntity detailEntity : entity.getBudgetProjectDetailList()) {
                    Long id = detailEntity.getId();
                    MaterialConjectureVO materialConjectureVO = map.get(id);
                    if (materialConjectureVO != null) {
                        detailEntity.setMateType(materialConjectureVO.getMateType());
                        if(ConjectureConstants.MATE_TYPE_COMPLETE_MATCH.equals(materialConjectureVO.getConjectureMateType())){
                            detailEntity.setMaterialId(materialConjectureVO.getActualMaterialId());
                            detailEntity.setMaterialCode(materialConjectureVO.getActualMaterialCode());
                            detailEntity.setMaterialName(materialConjectureVO.getActualMaterialName());
                            detailEntity.setMaterialSpec(materialConjectureVO.getActualMaterialSpec());
                        } else {
                            detailEntity.setMaterialId(null);
                            detailEntity.setMaterialCode(null);
                            detailEntity.setMaterialName(null);
                            detailEntity.setMaterialSpec(null);
                        }
                        detailEntities.add(detailEntity);
                    }
                }
                if (CollectionUtils.isNotEmpty(detailEntities)) {
                    detailService.saveOrUpdateBatch(detailEntities);
                }
                LambdaUpdateWrapper<BudgetProjectEntity> updateWrapper = new LambdaUpdateWrapper<>();
                updateWrapper.eq(BudgetProjectEntity::getId, billId);
                updateWrapper.set(BudgetProjectEntity::getIdentificationState, 2);
                budgetProjectService.update(updateWrapper);
            } else {
                BudgetProjectChangeEntity changeEntity = budgetProjectChangeService.selectById(billId);
                if (changeEntity != null) {
                    List<BudgetProjectDetailChangeEntity> detailEntities = new ArrayList<>();
                    for (BudgetProjectDetailChangeEntity detailEntity : changeEntity.getBudgetProjectDetailList()) {
                        Long id = detailEntity.getId();
                        MaterialConjectureVO materialConjectureVO = map.get(id);
                        if (materialConjectureVO != null) {
                            detailEntity.setMateType(materialConjectureVO.getMateType());
                            if (ConjectureConstants.MATE_TYPE_COMPLETE_MATCH.equals(materialConjectureVO.getConjectureMateType())) {
                                detailEntity.setMaterialId(materialConjectureVO.getActualMaterialId());
                                detailEntity.setMaterialCode(materialConjectureVO.getActualMaterialCode());
                                detailEntity.setMaterialName(materialConjectureVO.getActualMaterialName());
                                detailEntity.setMaterialSpec(materialConjectureVO.getActualMaterialSpec());
                            } else {
                                detailEntity.setMaterialId(null);
                                detailEntity.setMaterialCode(null);
                                detailEntity.setMaterialName(null);
                                detailEntity.setMaterialSpec(null);
                            }
                            detailEntities.add(detailEntity);
                        }
                    }
                    if (CollectionUtils.isNotEmpty(detailEntities)) {
                        detailChangeService.saveOrUpdateBatch(detailEntities);
                    }
                    LambdaUpdateWrapper<BudgetProjectChangeEntity> updateWrapper = new LambdaUpdateWrapper<>();
                    updateWrapper.eq(BudgetProjectChangeEntity::getId, billId);
                    updateWrapper.set(BudgetProjectChangeEntity::getIdentificationState, 2);
                    budgetProjectChangeService.update(updateWrapper);
                }
            }

            logger.info("updateMaterialConjecture回调-------{}---------", billId);
            String lockKey = "AiMaterialKey_" + billId;
            redissonLocker.unlock(lockKey);
        }
        return CommonResponse.success("更新物料识别结果数据成功！");
    }

    @ApiOperation("项目费用包接口")
    @RequestMapping(value = "/queryPackageList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<Map>> queryPackageList(@RequestBody BudgetProjectDetailQueryVO queryVO) {
        if (queryVO.getProjectSid() == null || queryVO.getPageSize() == null || queryVO.getPageIndex() == null) {
            throw new BusinessException("参数项目ID[projectId/projectSid]不能为空！");
        }
        if (queryVO.getPageSize() == null) {
            throw new BusinessException("参数每页行数[pageSize]不能为空！");
        }
        if (queryVO.getPageIndex() == null) {
            throw new BusinessException("参数页码[pageIndex]不能为空！");
        }
        Page<Map> page = new Page<>((long) queryVO.getPageIndex(), (long) queryVO.getPageSize());
        List<Map> list = service.queryPackageList(page, queryVO);
        for (Map map : list) {
            if (!map.containsKey("materialCode")){
                map.put("materialCode",null);
            }
            if (!map.containsKey("materialId")){
                map.put("materialId",null);
            }
            if (!map.containsKey("materialName")){
                map.put("materialName",null);
            }
            if (!map.containsKey("materialSpec")){
                map.put("materialSpec",null);
            }
        }
        IPage<Map> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(list);
        return CommonResponse.success("查询列表数据成功！", pageData);
    }


    @ApiOperation("切包清单接口")
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<Page<BudgetProjectDetailVO>> queryList(@RequestBody BudgetProjectDetailQueryVO queryVO) {
        if (queryVO.getProjectId() == null && queryVO.getProjectSid() == null) {
            throw new BusinessException("参数项目ID[projectId/projectSid]不能为空！");
        }
        LambdaQueryWrapper<BudgetProjectEntity> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(null != queryVO.getProjectSid(), BudgetProjectEntity::getProjectSid, queryVO.getProjectSid());
        queryWrapper.eq(null != queryVO.getProjectId(), BudgetProjectEntity::getProjectId, queryVO.getProjectId());
        queryWrapper.in(BudgetProjectEntity::getBillState, "1,3");
        queryWrapper.orderByDesc(BudgetProjectEntity::getCreateTime);
        List<BudgetProjectEntity> list1 = budgetProjectService.list(queryWrapper);
        Long budgetId = 1L;
        if (CollectionUtils.isNotEmpty(list1)) {
            budgetId = list1.get(0).getId();
        }

        QueryParam queryParam = new QueryParam();
        if (null != queryVO.getPageSize()) {
            queryParam.setPageSize(queryVO.getPageSize());
        }
        if (null != queryVO.getPageIndex()) {
            queryParam.setPageIndex(queryVO.getPageIndex());
        }
        Map<String, Parameter> params = queryParam.getParams();
        String paramStr = queryVO.getParamStr();
        if (StringUtils.isNotEmpty(paramStr)) {
            String[] split = paramStr.split(",");
            //专业编码,专业名称,包标识,包代码,包名称
            if (split.length > 0 && StringUtil.isNotBlank(split[0])) {
                params.put("bigPackCode", new Parameter(QueryParam.LIKE, split[0]));
            }
            if (split.length > 1 && StringUtil.isNotBlank(split[1])) {
                params.put("bigPackName", new Parameter(QueryParam.LIKE, split[1]));
            }
            if (split.length > 2 && StringUtil.isNotBlank(split[2])) {
                if ("engineering".equals(split[2])) {
                    params.put("engineeringListFlag", new Parameter(QueryParam.EQ, 1));
                } else {
                    params.put("materialListFlag", new Parameter(QueryParam.EQ, 1));
                }
            }
            if (split.length > 3 && StringUtil.isNotBlank(split[3])) {
                params.put("SQL", new Parameter(QueryParam.SQL, "(engineering_pack_code = '" + split[3] + "' or material_pack_code = '" + split[3] + "' )"));
            }
            if (split.length > 4 && StringUtil.isNotBlank(split[4])) {
                params.put("SQL", new Parameter(QueryParam.SQL, "(engineering_pack_name = '" + split[4] + "' or material_pack_name = '" + split[4] + "' )"));
            }
        }
        /** 租户隔离 */
        params.put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        params.put("budgetId", new Parameter(QueryParam.EQ, budgetId));
        params.put("changeType", new Parameter(QueryParam.NE, ChangTypeConst.DELETE));
        if (null != queryVO.getMaterialPackIds()) {
            params.put("materialPackId", new Parameter(QueryParam.IN, queryVO.getMaterialPackIds()));
        }
        if (null != queryVO.getMaterialPackCodes()) {
            params.put("materialPackCode", new Parameter(QueryParam.IN, queryVO.getMaterialPackCodes()));
        }
        if (null != queryVO.getBudgetDetailIds()) {
            params.put("id", new Parameter(QueryParam.IN, queryVO.getBudgetDetailIds()));
        }
        IPage<BudgetProjectDetailEntity> entityIPage = service.queryPage(queryParam, false);
        Page<BudgetProjectDetailVO> pageData = new Page<>(entityIPage.getCurrent(), entityIPage.getSize(), entityIPage.getTotal());
        List<BudgetProjectDetailVO> detailVOS = BeanMapper.mapList(entityIPage.getRecords(), BudgetProjectDetailVO.class);
        for (BudgetProjectDetailVO detailVO : detailVOS) {
            detailVO.setMaterialPackName(null != detailVO.getMaterialPackCode() ?
                    detailVO.getMaterialPackName() + detailVO.getMaterialPackCode() : detailVO.getMaterialPackName());
            detailVO.setEngineeringPackName(null != detailVO.getEngineeringPackCode() ?
                    detailVO.getEngineeringPackName() + detailVO.getEngineeringPackCode() : detailVO.getEngineeringPackName());
        }
        pageData.setRecords(detailVOS);
        return CommonResponse.success("查询列表数据成功！", pageData);
    }


}
